<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="26"/>
        <location filename="ui_mainwindow.h" line="756"/>
        <source>Network Assistant</source>
        <translation>Assistente de Redes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="86"/>
        <location filename="ui_mainwindow.h" line="799"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="109"/>
        <location filename="ui_mainwindow.h" line="803"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="177"/>
        <location filename="ui_mainwindow.h" line="805"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="184"/>
        <location filename="ui_mainwindow.h" line="807"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="219"/>
        <location filename="ui_mainwindow.h" line="770"/>
        <source>Status</source>
        <translation>Estado</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="225"/>
        <location filename="ui_mainwindow.h" line="757"/>
        <source>IP address</source>
        <translation>Endereço de IP</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="261"/>
        <location filename="ui_mainwindow.h" line="760"/>
        <source>Hardware detected</source>
        <translation>Dispositivo detectado</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="280"/>
        <source>Enable</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="303"/>
        <location filename="mainwindow.ui" line="593"/>
        <location filename="mainwindow.ui" line="706"/>
        <location filename="ui_mainwindow.h" line="761"/>
        <location filename="ui_mainwindow.h" line="774"/>
        <location filename="ui_mainwindow.h" line="780"/>
        <source>Re-scan</source>
        <translation>Voltar a procurar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="372"/>
        <source>Enabled</source>
        <translation>Ativado</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="377"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="382"/>
        <source>Driver</source>
        <translation>Controlador</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="387"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="392"/>
        <source>Vendor</source>
        <translation>Fornecedor</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="397"/>
        <source>Product</source>
        <translation>Produto</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="405"/>
        <source>Disable</source>
        <translation>Desativar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="419"/>
        <location filename="ui_mainwindow.h" line="762"/>
        <source>Active interface</source>
        <translation>Interface ativa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="435"/>
        <location filename="ui_mainwindow.h" line="764"/>
        <source>WiFi status</source>
        <translation>Estado do Wi-Fi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="457"/>
        <location filename="ui_mainwindow.h" line="767"/>
        <source>Unblocks all soft/hard blocked wireless devices</source>
        <translation>Desbloqueia todos os dispositivos sem fios (wireless) bloqueados por programa (software) ou no bloqueados por equipamento (soft/hard blocked)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="460"/>
        <location filename="ui_mainwindow.h" line="769"/>
        <source>Unblock WiFi Devices</source>
        <translation>Desbloquear os Dispositivos Wi-Fi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="492"/>
        <location filename="ui_mainwindow.h" line="776"/>
        <source>Linux drivers</source>
        <translation>Controladores do GNU/Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="504"/>
        <location filename="ui_mainwindow.h" line="771"/>
        <source>Associated Linux drivers</source>
        <translation>Controladores do GNU/Linux associados</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="513"/>
        <location filename="ui_mainwindow.h" line="772"/>
        <source>Load Driver</source>
        <translation>Instalar o Controlador</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="576"/>
        <location filename="ui_mainwindow.h" line="773"/>
        <source>Unload Driver</source>
        <translation>Desinstalar o Controlador</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="613"/>
        <location filename="mainwindow.cpp" line="833"/>
        <location filename="ui_mainwindow.h" line="775"/>
        <source>Block Driver</source>
        <translation>Bloquear o Controlador</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="632"/>
        <location filename="ui_mainwindow.h" line="785"/>
        <source>Windows drivers</source>
        <translation>Controladores do Windows</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="638"/>
        <location filename="ui_mainwindow.h" line="777"/>
        <source>Available Windows drivers</source>
        <translation>Controladores do Windows disponíveis</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="672"/>
        <location filename="ui_mainwindow.h" line="778"/>
        <source>Remove Driver</source>
        <translation>Remover o Controlador</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="683"/>
        <location filename="ui_mainwindow.h" line="779"/>
        <source>Add Driver</source>
        <translation>Adicionar o Controlador</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="724"/>
        <location filename="ui_mainwindow.h" line="781"/>
        <source>About NDISwrapper</source>
        <translation>Sobre o NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="736"/>
        <location filename="ui_mainwindow.h" line="782"/>
        <source>Install NDISwrapper</source>
        <translation>Instalar o NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="747"/>
        <location filename="ui_mainwindow.h" line="783"/>
        <source>In order to use Windows drivers you need first to install NDISwrapper</source>
        <translation>Para utilizar os controladores do Windows, você tem que instalar primeiro o NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="763"/>
        <location filename="ui_mainwindow.h" line="784"/>
        <source>Uninstall NDISwrapper</source>
        <translation>Desinstalar o NDISwrapper</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="795"/>
        <location filename="ui_mainwindow.h" line="798"/>
        <source>Net diagnostics</source>
        <translation>Diagnósticos de rede</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="807"/>
        <location filename="ui_mainwindow.h" line="786"/>
        <source>Ping</source>
        <translation>Ping</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="813"/>
        <location filename="mainwindow.ui" line="933"/>
        <location filename="ui_mainwindow.h" line="787"/>
        <location filename="ui_mainwindow.h" line="793"/>
        <source>Target URL:</source>
        <translation>URL do Alvo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="823"/>
        <location filename="ui_mainwindow.h" line="788"/>
        <source>Packets</source>
        <translation>Pacotes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="868"/>
        <location filename="mainwindow.ui" line="991"/>
        <location filename="ui_mainwindow.h" line="789"/>
        <location filename="ui_mainwindow.h" line="795"/>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="885"/>
        <location filename="mainwindow.ui" line="1008"/>
        <location filename="ui_mainwindow.h" line="790"/>
        <location filename="ui_mainwindow.h" line="796"/>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="899"/>
        <location filename="mainwindow.ui" line="1022"/>
        <location filename="ui_mainwindow.h" line="791"/>
        <location filename="ui_mainwindow.h" line="797"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="927"/>
        <location filename="ui_mainwindow.h" line="792"/>
        <source>Traceroute</source>
        <translation>Traceroute</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="943"/>
        <location filename="ui_mainwindow.h" line="794"/>
        <source>Hops</source>
        <translation>Saltos (Hops)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="86"/>
        <source>IP address from router:</source>
        <translation>Endereço de IP do roteador (router):</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="87"/>
        <source>External IP address:</source>
        <translation>Endereço de IP externo:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <location filename="mainwindow.cpp" line="137"/>
        <source>Interface: %1</source>
        <translation>Interface: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="124"/>
        <location filename="mainwindow.cpp" line="138"/>
        <source>Driver: %1</source>
        <translation>Controlador: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="125"/>
        <location filename="mainwindow.cpp" line="139"/>
        <source>Description: %1</source>
        <translation>Descrição: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="126"/>
        <location filename="mainwindow.cpp" line="140"/>
        <source>Product: %1</source>
        <translation>Produto: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="126"/>
        <location filename="mainwindow.cpp" line="141"/>
        <source>Vendor: %1</source>
        <translation>Fornecedor: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="127"/>
        <location filename="mainwindow.cpp" line="142"/>
        <source>Enabled: %1</source>
        <translation>Ativado: %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="195"/>
        <location filename="mainwindow.cpp" line="209"/>
        <location filename="mainwindow.cpp" line="223"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="197"/>
        <location filename="mainwindow.cpp" line="211"/>
        <location filename="mainwindow.cpp" line="225"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="198"/>
        <location filename="mainwindow.cpp" line="212"/>
        <location filename="mainwindow.cpp" line="226"/>
        <source>Copy &amp;All</source>
        <translation>&amp;Copiar Tudo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="200"/>
        <location filename="mainwindow.cpp" line="214"/>
        <location filename="mainwindow.cpp" line="228"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="260"/>
        <location filename="mainwindow.cpp" line="277"/>
        <source>Traceroute not installed</source>
        <translation>A rota de rastreamento (traceroute) não está instalada</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="261"/>
        <source>Traceroute is not installed, do you want to install it now?</source>
        <translation>A rota de rastreamento (traceroute) não está instalada, você quer instalá-lo agora?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="267"/>
        <source>Traceroute hasn&apos;t been installed</source>
        <translation>A rota de rastreamento (traceroute) ainda não foi instalada</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="268"/>
        <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
        <translation>Não foi possível instalar a rota de rastreamento (traceroute). Isto pode significar que você está utilizando a instalação externa ou não se consegue acessar o repositório de programas.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="278"/>
        <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
        <translation>A rota de rastreamento (traceroute) não está instalada. Não foi detectada nenhuma conexão com a Internet, portanto, não é possível continuar a sua instalação</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <location filename="mainwindow.cpp" line="330"/>
        <source>No destination host</source>
        <translation>Nenhum hospedeiro (host) como destino</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="285"/>
        <location filename="mainwindow.cpp" line="330"/>
        <source>Please fill in the destination host field</source>
        <translation>Por favor, preencha o campo do hospedeiro (host) de destino</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <source>Loaded Drivers</source>
        <translation>Controladores Carregados</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="454"/>
        <source>Unloaded Drivers</source>
        <translation>Controladores Não Carregados</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="468"/>
        <source>Blocked Drivers</source>
        <translation>Controladores Bloqueados</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="488"/>
        <source>Blocked Broadcom Drivers</source>
        <translation>Controladores Broadcom Bloqueados</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="510"/>
        <source>Ndiswrapper is not installed</source>
        <translation>O NDISwrapper não está instalado</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="523"/>
        <source>driver installed</source>
        <translation>controlador está instalado</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="532"/>
        <source> and in use by </source>
        <translation> e está em uso por </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="539"/>
        <source>. Alternate driver: </source>
        <translation>. Controlador alternativo: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist</source>
        <translation>O controlador foi removido da lista de bloqueio</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Driver removed from blocklist.</source>
        <translation>O controlador foi removido da lista de bloqueio</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="609"/>
        <source>Module blocked</source>
        <translation>Módulo bloqueado</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="763"/>
        <source>Installation successful</source>
        <translation>A instalação foi completada com sucesso</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="765"/>
        <source>Error detected, could not compile ndiswrapper driver.</source>
        <translation>Um erro foi detectado, não foi possível compilar o controlador do NDISwrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="768"/>
        <source>Error detected, could not install ndiswrapper.</source>
        <translation>Um erro foi detectado, não foi possível instalar o NDISwrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="780"/>
        <source>Error encountered while removing Ndiswrapper</source>
        <translation>Um erro foi detectado ao remover o NDISwrapper.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="830"/>
        <source>Unblock Driver</source>
        <translation>Desbloquear o Controlador</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="862"/>
        <source>enabled</source>
        <translation>ativado</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="865"/>
        <source>disabled</source>
        <translation>desativado</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="868"/>
        <source>WiFi hardware switch is off</source>
        <translation>O interruptor de Wi-Fi do computador está desligado</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="875"/>
        <source>Locate the Windows driver you want to add</source>
        <translation>Localizar o controlador (driver) do Windows que você quer adicionar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="876"/>
        <source>Windows installation information file (*.inf)</source>
        <translation>O arquivo de informações sobre a instalação Windows (*.inf)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="907"/>
        <source>*.sys file not found</source>
        <translation>não foi encontrado o arquivo  *.sys</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="908"/>
        <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
        <translation>Os arquivos *.sys têm que estar no mesmo local que o arquivo *.inf. Não foi encontrado o arquivo %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="919"/>
        <source>sys file reference not found</source>
        <translation>Não foi encontrada a referência do arquivo sys</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="920"/>
        <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
        <translation>O processo de análise sintática (parsing) do arquivo inf não permitiu determinar qual é o arquivo sys para o controlador (driver) em questão</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="937"/>
        <source>Ndiswrapper driver removed.</source>
        <translation>O controlador do NDISwrapper foi removido.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="945"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="957"/>
        <source>Could not unlock devices.
WiFi device(s) might already be unlocked.</source>
        <translation>Não foi possível desbloquear os dispositivos.
O(s) dispositivo(s) de rede sem fio pode(m) já estar desbloqueado(s).</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="959"/>
        <source>WiFi devices unlocked.</source>
        <translation>O(s) dispositivo(s) de rede sem fio está(ão) desbloqueado(s)</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="974"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="975"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="976"/>
        <source>Program for troubleshooting and configuring network for antiX Linux</source>
        <translation>Programa para solução de problemas e configurações de rede para o antiX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="978"/>
        <source>Copyright (c) MEPIS LLC and MX Linux</source>
        <translation>Direitos de Autor (c) MEPIS LLC e MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="979"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1005"/>
        <source>Driver loaded successfully</source>
        <translation>O controlador foi carregado com sucesso</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1020"/>
        <source>Driver unloaded successfully</source>
        <translation>O controlador foi descarregado com sucesso</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="about.cpp" line="52"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="about.cpp" line="53"/>
        <location filename="about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="about.cpp" line="76"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="main.cpp" line="70"/>
        <location filename="main.cpp" line="78"/>
        <source>Error</source>
        <translation>Ocorreu um erro</translation>
    </message>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Ao que parece, você está acessando a sessão com o usuário administrador (root). Por favor, saia da sessão atual e entre novamente com o usuário normal para utilizar este programa.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="79"/>
        <source>You must run this program with admin access.</source>
        <translation>Você tem que executar este programa com o usuário administrador.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="624"/>
        <source>Could not load </source>
        <translation>Não foi possível carregar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="649"/>
        <source>Could not unload </source>
        <translation>Não foi possível descarregar</translation>
    </message>
</context>
</TS>